summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xsource3/autogen.sh6
-rwxr-xr-xsource3/script/installman.sh2
2 files changed, 4 insertions, 4 deletions
diff --git a/source3/script/installman.sh b/source3/script/installman.sh
index 869ce6ee38..ab9bfe506d 100755
--- a/source3/script/installman.sh
+++ b/source3/script/installman.sh
@@ -14,7 +14,7 @@ if [ $# -ge 4 ] ; then
fi
if test ! -d $SRCDIR../docs/manpages; then
- echo "No manpages present. SVN development version maybe?"
+ echo "No manpages present. Development version maybe?"
exit 0
fi
diff --git a/source3/autogen.sh b/source3/autogen.sh
index 02f55c5421..018944e684 100755
--- a/source3/autogen.sh
+++ b/source3/autogen.sh
@@ -1,9 +1,9 @@
#!/bin/sh
# Run this script to build samba from SVN.
## insert all possible names (only works with
-## autoconf 2.x
+## autoconf 2.x)
TESTAUTOHEADER="autoheader autoheader-2.53 autoheader2.50 autoheader259 autoheader253"
TESTAUTOCONF="autoconf autoconf-2.53 autoconf2.50 autoconf259 autoconf253"
@@ -43,7 +43,7 @@ done
## do we have it?
##
if test "$AUTOCONFFOUND" = "0" -o "$AUTOHEADERFOUND" = "0"; then
- echo "$0: need autoconf 2.53 or later to build samba from SVN" >&2
+ echo "$0: need autoconf 2.53 or later to build samba from GIT" >&2
exit 1
fi
@@ -1,9 +1,9 @@
#!/bin/sh
-# Run this script to build samba from SVN.
+# Run this script to build samba from GIT.
## insert all possible names (only works with